#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gdk
version:                4.0.9
visibility:             public
id:                     gi-gdk-4.0.9-1L4RqtLfC2IC3EQHzzK5xy
key:                    gi-gdk-4.0.9-1L4RqtLfC2IC3EQHzzK5xy
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Gdk bindings
description:            Bindings for Gdk, autogenerated by haskell-gi.
category:               Bindings
abi:                    e4bd78d634541acac98a7ab4fa6518a9
exposed:                True
exposed-modules:
    GI.Gdk GI.Gdk.Callbacks GI.Gdk.Config GI.Gdk.Constants GI.Gdk.Enums
    GI.Gdk.Flags GI.Gdk.Functions GI.Gdk.Interfaces
    GI.Gdk.Interfaces.DevicePad GI.Gdk.Interfaces.DragSurface
    GI.Gdk.Interfaces.Paintable GI.Gdk.Interfaces.Popup
    GI.Gdk.Interfaces.Toplevel GI.Gdk.Objects
    GI.Gdk.Objects.AppLaunchContext GI.Gdk.Objects.ButtonEvent
    GI.Gdk.Objects.CairoContext GI.Gdk.Objects.CicpParams
    GI.Gdk.Objects.Clipboard GI.Gdk.Objects.ContentDeserializer
    GI.Gdk.Objects.ContentProvider GI.Gdk.Objects.ContentSerializer
    GI.Gdk.Objects.CrossingEvent GI.Gdk.Objects.Cursor
    GI.Gdk.Objects.DNDEvent GI.Gdk.Objects.DeleteEvent
    GI.Gdk.Objects.Device GI.Gdk.Objects.DeviceTool
    GI.Gdk.Objects.Display GI.Gdk.Objects.DisplayManager
    GI.Gdk.Objects.DmabufTexture GI.Gdk.Objects.DmabufTextureBuilder
    GI.Gdk.Objects.Drag GI.Gdk.Objects.DrawContext GI.Gdk.Objects.Drop
    GI.Gdk.Objects.Event GI.Gdk.Objects.FocusEvent
    GI.Gdk.Objects.FrameClock GI.Gdk.Objects.GLContext
    GI.Gdk.Objects.GLTexture GI.Gdk.Objects.GLTextureBuilder
    GI.Gdk.Objects.GrabBrokenEvent GI.Gdk.Objects.KeyEvent
    GI.Gdk.Objects.MemoryTexture GI.Gdk.Objects.MemoryTextureBuilder
    GI.Gdk.Objects.Monitor GI.Gdk.Objects.MotionEvent
    GI.Gdk.Objects.PadEvent GI.Gdk.Objects.ProximityEvent
    GI.Gdk.Objects.ScrollEvent GI.Gdk.Objects.Seat
    GI.Gdk.Objects.Snapshot GI.Gdk.Objects.Surface
    GI.Gdk.Objects.Texture GI.Gdk.Objects.TouchEvent
    GI.Gdk.Objects.TouchpadEvent GI.Gdk.Objects.VulkanContext
    GI.Gdk.Structs GI.Gdk.Structs.ColorState
    GI.Gdk.Structs.ContentFormats GI.Gdk.Structs.ContentFormatsBuilder
    GI.Gdk.Structs.DmabufFormats GI.Gdk.Structs.DragSurfaceSize
    GI.Gdk.Structs.EventSequence GI.Gdk.Structs.FileList
    GI.Gdk.Structs.FrameTimings GI.Gdk.Structs.KeymapKey
    GI.Gdk.Structs.PopupLayout GI.Gdk.Structs.RGBA
    GI.Gdk.Structs.Rectangle GI.Gdk.Structs.TextureDownloader
    GI.Gdk.Structs.TimeCoord GI.Gdk.Structs.ToplevelLayout
    GI.Gdk.Structs.ToplevelSize

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gdk-4.0.9
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-gdk-4.0.9 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-gdk-4.0.9 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gdk
hs-libraries:           HSgi-gdk-4.0.9-1L4RqtLfC2IC3EQHzzK5xy
extra-libraries:
    gtk-4 pangocairo-1.0 pango-1.0 harfbuzz gdk_pixbuf-2.0
    cairo-gobject cairo vulkan graphene-1.0 gio-2.0 gobject-2.0
    glib-2.0

extra-libraries-static:
    gtk-4 pangocairo-1.0 m pangoft2-1.0 m pango-1.0 m fribidi thai
    datrie Xft harfbuzz-gobject harfbuzz m graphite2 gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread cairo-gobject m dl cairo m dl
    fontconfig m expat m freetype dl bz2 png16 m m brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m vulkan graphene-1.0 m gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 atomic m pcre2-8 pthread z mount blkid systemd
    sysprof-capture-4

include-dirs:
    /usr/include/gtk-4.0 /usr/include/pango-1.0 /usr/include/fribidi
    /usr/include /usr/include/harfbuzz /usr/include/gdk-pixbuf-2.0
    /usr/include/glycin-2 /usr/include/cairo /usr/include/freetype2
    /usr/include/libpng16 /usr/include/pixman-1
    /usr/include/graphene-1.0 /usr/lib/graphene-1.0/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-cairo-1.0.30-Lws0CVlELgrHNg1FAdcAGa
    gi-gdkpixbuf-2.0.32-Lh2dyZGEqsUAihaCiGKMzR
    gi-gio-2.0.38-LMYUMP0kzXo8NdirsGppho
    gi-glib-2.0.30-9KAwSjfUuiEh2h2Gl2wXP
    gi-gobject-2.0.31-5lXdZZXKGd6KPMG8BfmwwE
    gi-pango-1.0.30-DzEutonY1DeIobYbDchWns
    haskell-gi-0.26.17-AHOlTfNVQ7XIzcJSXVZXRK
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gdk/html/gi-gdk.haddock
haddock-html:           /usr/share/doc/haskell-gi-gdk/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

